function [r,IRES1,IRES2] = gofg_motif(...
gamma, inidim,indice, X,Y, IRES1P,IRES2P,elem, k,delta, w,Hg)

%gofg_motif: log-relative posterior probability of gamma. 
%   (Modified code - fast form of updating is not used)
%*******************************************************************
%INPUTS:
% gamma,          binary vector
% inidim      maximum dimension for the fast form of updating   
% indice,         1 -- QR decomp
%                 2 -- QRinsert
%                 3 -- QRdelete
% X,          independent variables, n by p
% Y,              augmented response matrix, (n+p) by q
% IRES1P,IRSE2P,  binary matrices for fast form of updating
% elem,           position to add/delete
% k,delta,        hyperparameters of Inverse Wishart prior
% w,              hyperparameters of prior on latent binary vector
% Hg,             hyperparameter of prior on regression coefficients 
%
%OUTPUTS:
% r,              log-relative posterior probability of gamma
% IRES1,IRES2,    binary matrices for fast form of updating
%
%USAGE:
% [r, IRES1,IRES2]= gofg_motif(...
% gamma,inidim,indice,X,Y,IRES1P,IRES2P,elem,k,delta,w,Hg);
%
%NOTES:
% Called by bvsme_motif and metro_motif
%
%REFERENCE:
%
% Tadesse, M.G., Vannucci, M. and Lio', P. (2004). 
% Identification of DNA regulatory motifs using Bayesian variable selection. 
% Bioinformatics, 20(16), 2553-2561. 
%
%Copyright (c) 2001-2004 Marina Vannucci.
%**********************************************************************

[nOss p]=size(X);
[q]=size(Y,2);
Qk=k*eye(q);                         
I=find(gamma);
nonnulle=length(I);
switch indice
    case 1  % ------------------ Indice = 1 -- QR Decomposition

        XGam=X(:,I);
        if (size(Hg,1)==1 | size(Hg,2)==1) % diagonal prior 
                
            IRES1=eye(inidim);
            IRES2=IRES1(:,1:nonnulle);   
            IRES1(:,1:nonnulle)=[]; 
            moltiplica=diag(Hg(I));     
            Xtilde=cat(1,XGam*moltiplica, IRES2);
            % [Qqr Rqr]=qr(Xtilde);  
            Qqr=[]; Rqr=[];

        else  % non-diagonal prior  
              % OPTION NOT USED
        end             
        
    case 2  %------------------- Indice = 2 -- QRinsert
    
       % NOT USED

    case 3  %------------------- Indice = 3 -- QRdelete
       
        % NOT USED
end
%---------------------------------- prior of gamma
if (length(w)==1 | length(w)==p)
    prog=sum(log((w.^gamma).*(1-w).^(1-gamma)));
elseif length(w)==2
    alpha=w(2)*w(1);    % Beta prior (mean=pw(1), w(2)=alpha+beta) 
    betapar=w(2)*(1-w(1));
    gami=sum(gamma);
    prog=(gammaln(alpha+gami)+gammaln(p+betapar-gami))- ...
          gammaln(p+betapar+alpha);
end

%----------------------------------- log-relative posterior prob of gamma

RSP=Y'*Y-Y'*Xtilde*inv(Xtilde'*Xtilde)*Xtilde'*Y;    
Qstar=Qk+RSP;                   % q by q
detH0K=det(Xtilde'*Xtilde);
r= -(q/2)*log(detH0K)-((delta+nOss+q-1)/2)*log(det(Qstar))+prog;
