function [UniSt,ProbSt, GammaSt, storeAD, storeS]= ... 
metro_motif(inidim,gamprec,probprec,X,Ytilde,IRES1P, IRES2P, ...
k,delta,w,Hg,nPar,pPar);

%metro_motif: Metropolis - Selection prior 
% (Modified code - fast form of updating not used)
%**********************************************************************
%INPUTS:
% inidim      maximum dimension for the fast form of updating   
% gamprec,        initial binary vector.
% probprec,   log-relative posterior probability of gamprec
% X,              independent variables, n by p
% Ytilde,         augmented response matrix, (n+inidim) by q
% IRES1P,IRSE2P,  binary matrices for fast form of updating
% k,delta,        hyperparameters Inverse Wishart
% w,              hyperparameter (Bernoulli priors)
% Hg,         hyperparameter - prior on regression coefficients
% nPar,           number of iterations
% pPar,           probabitity of Addition/Deletion
%
%OUTPUTS:
% ProbSt,     log-relative posterior probabilities
%                 of visited vectors
% GammaSt,        cell with positions of 1's in visited vectors
% storeAD,storeS, iteration numbers of accepted additions/deletions (AD)
%                 and swaps (S)
%
%USAGE:
% [ProbSt, GammaSt, storeAD, storeS]= metro_motif(...
% gamprec,probprec,X,Ytilde,IRES1P,IRES2P,k,delta,w,Hg,nPar,pPar);
%
%NOTES:
% Called by bvsme_motif
% Functions called: gofg_motif
% An adding move is forced with empty model
% A delete move is forced with full model
%
%REFERENCE:
%   
% Tadesse, M.G., Vannucci, M. and Lio', P. (2004). 
% Identification of DNA regulatory motifs using Bayesian variable selection. 
% Bioinformatics, 20(16), 2553-2561.  
%       
%Copyright (c) 2001-2004 Marina Vannucci.
%**********************************************************************

[nOss p]=size(X);
[q]=size(Ytilde,2);
storeAD=[];
storeS=[];
GammaSt=cell(nPar,1);
ProbSt=zeros(1,nPar);
UniSt=zeros(1,nPar);

for i=1:nPar
    flag=0;
    gamnew=gamprec;
    poszeros=find(gamprec==0);
    if length(poszeros)==p          % Forced to add variable
        chi='AD';
        choice=ceil(rand(1)*p);
        gamnew(choice)=1;
        if (size(Hg,1)==1 | size(Hg,2)==1)%---diagonal prior
            
%-------------------Reset of limit size of IRES1 and IRES2      
            if size(IRES1P,2)==0
                flag=1;
                Ytilde(nOss+inidim+1,:)=zeros(1,q);
                inidim=inidim+1;
                [probnew, IRES1N,IRES2N] = ...
                gofg_motif(gamnew,inidim,1, X,Ytilde, ...
                [],[],[],k,delta,w,Hg);
            else                
                [probnew, IRES1N,IRES2N] = ...
                gofg_motif(gamnew,inidim,1, X, Ytilde, ...
                IRES1P,IRES2P, choice, ...
                k,delta, w,Hg);     
            end
        else    %-------- non-diagonal prior
                % OPTION NOT USED   
        end 
    elseif  isempty(poszeros)              % Forced to delete variable
        chi='AD';
        choice=ceil(rand(1)*p);
        gamnew(choice)=0;
        if ~ismember(1,size(Hg))  %--- non-diagonal prior
                                  % OPTION NOT USED

        else    %----- diagonal prior
                        
            [probnew, IRES1N,IRES2N] = ...
                        gofg_motif(gamnew,inidim,1, X, Ytilde, ...
            IRES1P, IRES2P,choice, k,delta,w,Hg);
        end 
        
    else            
        x=rand(1);
        if x<pPar

%-------------------Adding/Deleting
            chi='AD';
            choice=ceil(rand(1)*p);
            if gamnew(choice)==0
                gamnew(choice)=1;   
                if (size(Hg,1)==1 | size(Hg,2)==1)
                            %--- diagonal prior
            
%-------------------Reset of limit size of IRES1 and IRES2      
                    if size(IRES1P,2)==0
                        flag=1;
                        Ytilde(nOss+inidim+1,:)=zeros(1,q);
                        inidim=inidim+1;
                        [probnew,IRES1N,IRES2N] = ...
                        gofg_motif(gamnew,inidim,1,X, ...
                        Ytilde,[],[],[],k,delta,w,Hg);
                    else                
                        [probnew,IRES1N,IRES2N] = ...
                        gofg_motif(gamnew,inidim,1,X, ...
                        Ytilde,IRES1P,IRES2P,... 
                        choice,k,delta,w,Hg);       
                    end
                else    %-------- non-diagonal prior
                        % OPTION NOT USED                   
                end 
            else
                gamnew(choice)=0;
                if ~ismember(1,size(Hg)) %-- non-diagonal prior
                                         % OPTION NOT USED

                else    %----- diagonal prior
                 
                    [probnew,IRES1N,IRES2N] = ...
                                gofg_motif(gamnew,inidim,1,X,Ytilde, ...
                    IRES1P,IRES2P,choice,k, ...
                    delta,w,Hg);
                end 
            end
        else

%-------------------Swapping
            chi='S';
            poszeros=find(gamprec==0);
            posones=find(gamprec==1);
            choice1=ceil(rand(1)*length(poszeros));
            choice2=ceil(rand(1)*length(posones));
            elem=posones(choice2);
            gamnew(elem)=0;
            if ~ismember(1,size(Hg))  %--- non-diagonal prior
                                      % OPTION NOT USED

            else    %----- diagonal prior
                        
                [probnew, IRES1N,IRES2N]=gofg_motif(...
                gamnew,inidim,1,X,Ytilde,IRES1P, ...
                IRES2P,elem,k,delta,w,Hg);
            end 
                    elem=poszeros(choice1);  
            gamnew(elem)=1;
            if ~ismember(1,size(Hg))  %--- non-diagonal prior
                                      % OPTION NOT USED
                                      
            else    %----- diagonal prior
             
                [probnew,IRES1N,IRES2N]=gofg_motif(...
                gamnew,inidim,1,X,Ytilde,IRES1N, ...
                IRES2N,elem,k,delta,w,Hg);
            end
        end
    end 
    move=min(0, (probnew-probprec) );
    if move==0
        eval(['store',chi,'=[store',chi,' i];'])
        IRES1P=IRES1N;
        IRES2P=IRES2N;
                probprec=probnew;
                gamprec=gamnew;   
                ProbSt(i)=probnew;     
                GammaSt{i}=num2str(find(gamnew));
        UniSt(i)=length(find(gamnew));
    else if (rand(1) < exp(move))
            eval(['store',chi,'=[store',chi,' i];'])
            IRES1P=IRES1N;
            IRES2P=IRES2N;
            probprec=probnew;
            gamprec=gamnew;
            ProbSt(i)=probnew;
            GammaSt{i}=num2str(find(gamnew));       
            UniSt(i)=length(find(gamnew));
        else
            ProbSt(i)=probprec; 
            GammaSt{i}=num2str(find(gamprec));
            UniSt(i)=length(find(gamprec));
        
            if (size(Hg,1)==1 | size(Hg,2)==1) %---- diag prior
                if flag==1 
                    Ytilde(nOss+inidim,:)=[];
                    inidim=inidim-1; 
                else
                end
            else    
            end
        end
    end
end
